from typing import List, Tuple
from dataclasses import dataclass

from amulet_nbt import (
    ByteTag,
    ShortTag,
    IntTag,
    LongTag,
    FloatTag,
    DoubleTag,
    ByteArrayTag,
    IntArrayTag,
    LongArrayTag,
    StringTag,
    ListTag,
    CompoundTag,
    BaseNamedTag,
    NamedByteTag,
    NamedShortTag,
    NamedIntTag,
    NamedLongTag,
    NamedFloatTag,
    NamedDoubleTag,
    NamedByteArrayTag,
    NamedStringTag,
    NamedListTag,
    NamedCompoundTag,
    NamedIntArrayTag,
    NamedLongArrayTag,
)


@dataclass
class Bin:
    named_tag: BaseNamedTag
    big_endian: bytes
    little_endian: bytes
    big_endian_compressed: bytes
    little_endian_compressed: bytes
    snbt: str


binary_data: List[Tuple[BaseNamedTag, bytes, bytes, bytes, bytes, str]] = [
    (
        NamedByteTag(ByteTag(5), ""),
        b"\x01\x00\x00\x05",
        b"\x01\x00\x00\x05",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcd``\x05\x00\xf6L\x92\xe9\x04\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcd``\x05\x00\xf6L\x92\xe9\x04\x00\x00\x00",
        "5b",
    ),
    (
        NamedByteTag(ByteTag(-5), ""),
        b"\x01\x00\x00\xfb",
        b"\x01\x00\x00\xfb",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcd`\xf8\r\x00\xed\x93\x97\xb3\x04\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcd`\xf8\r\x00\xed\x93\x97\xb3\x04\x00\x00\x00",
        "-5b",
    ),
    (
        NamedShortTag(ShortTag(5), ""),
        b"\x02\x00\x00\x00\x05",
        b"\x02\x00\x00\x05\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcb```\x05\x00\xf2P\x88\xcc\x05\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcb``e\x00\x008P\x95\xc1\x05\x00\x00\x00",
        "5s",
    ),
    (
        NamedShortTag(ShortTag(-5), ""),
        b"\x02\x00\x00\xff\xfb",
        b"\x02\x00\x00\xfb\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcb`\xf8\xff\x1b\x00\x9br\xa9\x05\x05\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcb`\xf8\xfd\x1f\x00\x86s\xa8f\x05\x00\x00\x00",
        "-5s",
    ),
    (
        NamedIntTag(IntTag(5), ""),
        b"\x03\x00\x00\x00\x00\x00\x05",
        b"\x03\x00\x00\x05\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcf\x00\x01V\x00l1\xee\xdc\x07\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcf``e``\x00\x00\xd15Z\x9b\x07\x00\x00\x00",
        "5",
    ),
    (
        NamedIntTag(IntTag(-5), ""),
        b"\x03\x00\x00\xff\xff\xff\xfb",
        b"\x03\x00\x00\xfb\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcf`\xf8\xff\xff\xffo\x00\x19!Ru\x07\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcf`\xf8\xfd\xff\xff\x7f\x00Wr]\xfd\x07\x00\x00\x00",
        "-5",
    ),
    (
        NamedLongTag(LongTag(5), ""),
        b"\x04\x00\x00\x00\x00\x00\x00\x00\x00\x00\x05",
        b"\x04\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffca\x80\x01V\x00\xe164\xab\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffca``e\x80\x00\x00\n\xcc\xbe\x93\x0b\x00\x00\x00",
        "5L",
    ),
    (
        NamedLongTag(LongTag(-5), ""),
        b"\x04\x00\x00\xff\xff\xff\xff\xff\xff\xff\xfb",
        b"\x04\x00\x00\xfb\xff\xff\xff\xff\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffca`\xf8\x0f\x01\xbf\x01\x02\x06U\x98\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffca`\xf8\xfd\x1f\x02\x00\xe1\xccr\x1b\x0b\x00\x00\x00",
        "-5L",
    ),
    (
        NamedFloatTag(FloatTag(5.0), ""),
        b"\x05\x00\x00@\xa0\x00\x00",
        b"\x05\x00\x00\x00\x00\xa0@",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffce`pX\xc0\xc0\x00\x00\x84\xf58\x8d\x07\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffce\x00\x82\x05\x0e\x00\xa0\r\x8f\x17\x07\x00\x00\x00",
        "5.0f",
    ),
    (
        NamedFloatTag(FloatTag(-5.0), ""),
        b"\x05\x00\x00\xc0\xa0\x00\x00",
        b"\x05\x00\x00\x00\x00\xa0\xc0",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffce`8\xb0\x80\x81\x01\x00\xbfCa`\x07\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffce\x00\x82\x05\x07\x00\x80\x8e7\xfa\x07\x00\x00\x00",
        "-5.0f",
    ),
    (
        NamedDoubleTag(DoubleTag(5.0), ""),
        b"\x06\x00\x00@\x14\x00\x00\x00\x00\x00\x00",
        b"\x06\x00\x00\x00\x00\x00\x00\x00\x00\x14@",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcc`p\x10a\x00\x03\x00\x9f\x01>9\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcc\x80\x02\x11\x07\x00j\xed@\xdb\x0b\x00\x00\x00",
        "5.0d",
    ),
    (
        NamedDoubleTag(DoubleTag(-5.0), ""),
        b"\x06\x00\x00\xc0\x14\x00\x00\x00\x00\x00\x00",
        b"\x06\x00\x00\x00\x00\x00\x00\x00\x00\x14\xc0",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcc`8 \xc2\x00\x06\x00E\x84\x05j\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcc\x80\x02\x91\x03\x00Jn\xf86\x0b\x00\x00\x00",
        "-5.0d",
    ),
    (
        NamedByteArrayTag(ByteArrayTag([]), ""),
        b"\x07\x00\x00\x00\x00\x00\x00",
        b"\x07\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcg\x00\x03\x00\xf0\xe1\xcbX\x07\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcg\x00\x03\x00\xf0\xe1\xcbX\x07\x00\x00\x00",
        "[B;]",
    ),
    (
        NamedByteArrayTag(ByteArrayTag([5, 6, 7]), ""),
        b"\x07\x00\x00\x00\x00\x00\x03\x05\x06\x07",
        b"\x07\x00\x00\x03\x00\x00\x00\x05\x06\x07",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcg\x00\x01fV6v\x00/,\x16\xdd\n\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcg``f```ec\x07\x00\\\x99K\xfe\n\x00\x00\x00",
        "[B;5B, 6B, 7B]",
    ),
    (
        NamedByteArrayTag(ByteArrayTag([-5, -6, -7]), ""),
        b"\x07\x00\x00\x00\x00\x00\x03\xfb\xfa\xf9",
        b"\x07\x00\x00\x03\x00\x00\x00\xfb\xfa\xf9",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcg\x00\x01\xe6\xdf\xbf~\x02\x00_\x03@\x80\n\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcg``f``\xf8\xfd\xeb'\x00,\xb6\x1d\xa3\n\x00\x00\x00",
        "[B;-5B, -6B, -7B]",
    ),
    (
        NamedIntArrayTag(IntArrayTag([]), ""),
        b"\x0b\x00\x00\x00\x00\x00\x00",
        b"\x0b\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3f\x00\x03\x00\x84\x8bk\x9f\x07\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3f\x00\x03\x00\x84\x8bk\x9f\x07\x00\x00\x00",
        "[I;]",
    ),
    (
        NamedIntArrayTag(IntArrayTag([5, 6, 7]), ""),
        b"\x0b\x00\x00\x00\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x06\x00\x00\x00\x07",
        b"\x0b\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x06\x00\x00\x00\x07\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3f\x00\x01f f\x05b6 f\x07\x00\xc1\x1b\x86\x96\x13\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3f``f```\x05b6 f\x07b\x00\x9f\xa0,\x9a\x13\x00\x00\x00",
        "[I;5, 6, 7]",
    ),
    (
        NamedIntArrayTag(IntArrayTag([-5, -6, -7]), ""),
        b"\x0b\x00\x00\x00\x00\x00\x03\xff\xff\xff\xfb\xff\xff\xff\xfa\xff\xff\xff\xf9",
        b"\x0b\x00\x00\x03\x00\x00\x00\xfb\xff\xff\xff\xfa\xff\xff\xff\xf9\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3f\x00\x01\xe6\xff\xff\xff\xff\x06\xe2_@\xfc\x13\x00!|\x16q\x13\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3f``f``\xf8\xfd\xff\xff\xff_@\xfc\x13\x88\x01\x93\xb5\xf6\xf7\x13\x00\x00\x00",
        "[I;-5, -6, -7]",
    ),
    (
        NamedLongArrayTag(LongArrayTag([]), ""),
        b"\x0c\x00\x00\x00\x00\x00\x00",
        b"\x0c\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3a\x00\x03\x00\n\xb5\xccZ\x07\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3a\x00\x03\x00\n\xb5\xccZ\x07\x00\x00\x00",
        "[L;]",
    ),
    (
        NamedLongArrayTag(LongArrayTag([5, 6, 7]), ""),
        b"\x0c\x00\x00\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07",
        b"\x0c\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3a\x00\x01f\x06\x08`\x85\xd2lP\x9a\x1d\x00\x8a\xff\x94\t\x1f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3a``f```e\x80\x006(\xcd\x0e\xa5\x01\xde\xd5\x00\x96\x1f\x00\x00\x00",
        "[L;5L, 6L, 7L]",
    ),
    (
        NamedLongArrayTag(LongArrayTag([-5, -6, -7]), ""),
        b"\x0c\x00\x00\x00\x00\x00\x03\xff\xff\xff\xff\xff\xff\xff\xfb\xff\xff\xff\xff\xff\xff\xff\xfa\xff\xff\xff\xff\xff\xff\xff\xf9",
        b"\x0c\x00\x00\x03\x00\x00\x00\xfb\xff\xff\xff\xff\xff\xff\xff\xfa\xff\xff\xff\xff\xff\xff\xff\xf9\xff\xff\xff\xff\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3a\x00\x01\xe6\xff\x10\xf0\x1bJ\xff\x82\xd2?\x01x\xe4\xa4\xbf\x1f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3a``f``\xf8\xfd\x1f\x02~A\xe9\x9fP\x1a\x00w\xd8[\x8d\x1f\x00\x00\x00",
        "[L;-5L, -6L, -7L]",
    ),
    (
        NamedStringTag(StringTag("value"), ""),
        b"\x08\x00\x00\x00\x05value",
        b"\x08\x00\x00\x05\x00value",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3````-K\xcc)M\x05\x00\x18\x16\xc5{\n\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3```e(K\xcc)M\x05\x00\x0c\xa80y\n\x00\x00\x00",
        '"value"',
    ),
    (
        NamedListTag(ListTag([], 1), ""),
        b"\t\x00\x00\x01\x00\x00\x00\x00",
        b"\t\x00\x00\x01\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``d\x00\x02\x00\xf2\xed\rG\x08\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``d\x00\x02\x00\xf2\xed\rG\x08\x00\x00\x00",
        "[]",
    ),
    (
        NamedCompoundTag(CompoundTag({}), ""),
        b"\n\x00\x00\x00",
        b"\n\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``\x00\x00x?\xf9N\x04\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``\x00\x00x?\xf9N\x04\x00\x00\x00",
        "{}",
    ),
    (
        NamedListTag(ListTag([ByteTag(5)], 1), ""),
        b"\t\x00\x00\x01\x00\x00\x00\x01\x05",
        b"\t\x00\x00\x01\x01\x00\x00\x00\x05",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``d\x00bV\x00\x9e\xb4\x87\xe8\t\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``dd```\x05\x00o\xac\xfc\xcc\t\x00\x00\x00",
        "[5b]",
    ),
    (
        NamedListTag(ListTag([ByteTag(-5)], 1), ""),
        b"\t\x00\x00\x01\x00\x00\x00\x01\xfb",
        b"\t\x00\x00\x01\x01\x00\x00\x00\xfb",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``d\x00\xe2\xdf\x00\x85k\x82\xb2\t\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``dd``\xf8\r\x00ts\xf9\x96\t\x00\x00\x00",
        "[-5b]",
    ),
    (
        NamedListTag(ListTag([ShortTag(5)], 2), ""),
        b"\t\x00\x00\x02\x00\x00\x00\x01\x00\x05",
        b"\t\x00\x00\x02\x01\x00\x00\x00\x05\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``b```d`\x05\x00-\xcc\xa8\xf9\n\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``bd```e\x00\x00uu+>\n\x00\x00\x00",
        "[5s]",
    ),
    (
        NamedListTag(ListTag([ShortTag(-5)], 2), ""),
        b"\t\x00\x00\x02\x00\x00\x00\x01\xff\xfb",
        b"\t\x00\x00\x02\x01\x00\x00\x00\xfb\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``b```\xfc\xff\x1b\x00D\xee\x890\n\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``bd``\xf8\xfd\x1f\x00\xcbV\x16\x99\n\x00\x00\x00",
        "[-5s]",
    ),
    (
        NamedListTag(ListTag([IntTag(5)], 3), ""),
        b"\t\x00\x00\x03\x00\x00\x00\x01\x00\x00\x00\x05",
        b"\t\x00\x00\x03\x01\x00\x00\x00\x05\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``f```\x04bV\x00\x04\x1d\xfb\x92\x0c\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``fd```\x05b\x00\x970\x85$\x0c\x00\x00\x00",
        "[5]",
    ),
    (
        NamedListTag(ListTag([IntTag(-5)], 3), ""),
        b"\t\x00\x00\x03\x00\x00\x00\x01\xff\xff\xff\xfb",
        b"\t\x00\x00\x03\x01\x00\x00\x00\xfb\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``f```\xfc\xff\xff\xffo\x00q\rG;\x0c\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``fd``\xf8\xfd\xff\xff\x7f\x00\x11w\x82B\x0c\x00\x00\x00",
        "[-5]",
    ),
    (
        NamedListTag(ListTag([LongTag(5)], 4), ""),
        b"\t\x00\x00\x04\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x05",
        b"\t\x00\x00\x04\x01\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``a```d\x80\x00V\x00\xd1\xcfh\x96\x10\x00\x00\x00",
        b'\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``ad```e\x80\x00\x00\x16m<"\x10\x00\x00\x00',
        "[5L]",
    ),
    (
        NamedListTag(ListTag([LongTag(-5)], 4), ""),
        b"\t\x00\x00\x04\x00\x00\x00\x01\xff\xff\xff\xff\xff\xff\xff\xfb",
        b"\t\x00\x00\x04\x01\x00\x00\x00\xfb\xff\xff\xff\xff\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``a```\xfc\x0f\x01\xbf\x012\xff\t\xa5\x10\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``ad``\xf8\xfd\x1f\x02\x00\xfdm\xf0\xaa\x10\x00\x00\x00",
        "[-5L]",
    ),
    (
        NamedListTag(ListTag([FloatTag(5.0)], 5), ""),
        b"\t\x00\x00\x05\x00\x00\x00\x01@\xa0\x00\x00",
        b"\t\x00\x00\x05\x01\x00\x00\x00\x00\x00\xa0@",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``e```tX\xc0\xc0\x00\x00\\\x95\xe7\xd3\x0c\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``ed\x00\x81\x05\x0e\x00VD\x9a\xb8\x0c\x00\x00\x00",
        "[5.0f]",
    ),
    (
        NamedListTag(ListTag([FloatTag(-5.0)], 5), ""),
        b"\t\x00\x00\x05\x00\x00\x00\x01\xc0\xa0\x00\x00",
        b"\t\x00\x00\x05\x01\x00\x00\x00\x00\x00\xa0\xc0",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``e```<\xb0\x80\x81\x01\x00g#\xbe>\x0c\x00\x00\x00",
        b'\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``ed\x00\x81\x05\x07\x00v\xc7"U\x0c\x00\x00\x00',
        "[-5.0f]",
    ),
    (
        NamedListTag(ListTag([DoubleTag(5.0)], 6), ""),
        b"\t\x00\x00\x06\x00\x00\x00\x01@\x14\x00\x00\x00\x00\x00\x00",
        b"\t\x00\x00\x06\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x14@",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``c```t\x10a\x00\x03\x00%\xf4R<\x10\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``cd\x80\x01\x11\x07\x00\xfc@\xf2R\x10\x00\x00\x00",
        "[5.0d]",
    ),
    (
        NamedListTag(ListTag([DoubleTag(-5.0)], 6), ""),
        b"\t\x00\x00\x06\x00\x00\x00\x01\xc0\x14\x00\x00\x00\x00\x00\x00",
        b"\t\x00\x00\x06\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x14\xc0",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``c```< \xc2\x00\x06\x00\xffqio\x10\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``cd\x80\x01\x91\x03\x00\xdc\xc3J\xbf\x10\x00\x00\x00",
        "[-5.0d]",
    ),
    (
        NamedListTag(ListTag([ByteArrayTag([])], 7), ""),
        b"\t\x00\x00\x07\x00\x00\x00\x01\x00\x00\x00\x00",
        b"\t\x00\x00\x07\x01\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``g```\x04b\x06\x00\x87\xb8}\xbf\x0c\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``gd\x80\x00\x00\xa9\x91\xb7N\x0c\x00\x00\x00",
        "[[B;]]",
    ),
    (
        NamedListTag(ListTag([ByteArrayTag([5, 6, 7])], 7), ""),
        b"\t\x00\x00\x07\x00\x00\x00\x01\x00\x00\x00\x03\x05\x06\x07",
        b"\t\x00\x00\x07\x01\x00\x00\x00\x03\x00\x00\x00\x05\x06\x07",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``g```\x04bfV6v\x00\xb9\xa2\xd3\xc5\x0f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``gd```\x06bV6v\x00\x94\xc8\xaa\xeb\x0f\x00\x00\x00",
        "[[B;5B, 6B, 7B]]",
    ),
    (
        NamedListTag(ListTag([ByteArrayTag([-5, -6, -7])], 7), ""),
        b"\t\x00\x00\x07\x00\x00\x00\x01\x00\x00\x00\x03\xfb\xfa\xf9",
        b"\t\x00\x00\x07\x01\x00\x00\x00\x03\x00\x00\x00\xfb\xfa\xf9",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``g```\x04b\xe6\xdf\xbf~\x02\x00\xc9\x8d\x85\x98\x0f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d``gd```\x06\xe2\xdf\xbf~\x02\x00\xe4\xe7\xfc\xb6\x0f\x00\x00\x00",
        "[[B;-5B, -6B, -7B]]",
    ),
    (
        NamedListTag(ListTag([IntArrayTag([])], 11), ""),
        b"\t\x00\x00\x0b\x00\x00\x00\x01\x00\x00\x00\x00",
        b"\t\x00\x00\x0b\x01\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0f```\x04b\x06\x00\x93KIY\x0c\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0fd\x80\x00\x00\xbdb\x83\xa8\x0c\x00\x00\x00",
        "[[I;]]",
    ),
    (
        NamedListTag(ListTag([IntArrayTag([5, 6, 7])], 11), ""),
        b"\t\x00\x00\x0b\x00\x00\x00\x01\x00\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x06\x00\x00\x00\x07",
        b"\t\x00\x00\x0b\x01\x00\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x06\x00\x00\x00\x07\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0f```\x04bf f\x05b6 f\x07\x00\xed\x9a\xda\xcf\x18\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0fd```\x06bV f\x03bv \x06\x00\xb6\xd1\xb1!\x18\x00\x00\x00",
        "[[I;5, 6, 7]]",
    ),
    (
        NamedListTag(ListTag([IntArrayTag([-5, -6, -7])], 11), ""),
        b"\t\x00\x00\x0b\x00\x00\x00\x01\x00\x00\x00\x03\xff\xff\xff\xfb\xff\xff\xff\xfa\xff\xff\xff\xf9",
        b"\t\x00\x00\x0b\x01\x00\x00\x00\x03\x00\x00\x00\xfb\xff\xff\xff\xfa\xff\xff\xff\xf9\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0f```\x04b\xe6\xff\xff\xff\xff\x06\xe2_@\xfc\x13\x00\r\xfdJ(\x18\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0fd```\x06\xe2\xdf\xff\xff\xff\xff\x05\xc4?\x81\x18\x00\xba\xc4kL\x18\x00\x00\x00",
        "[[I;-5, -6, -7]]",
    ),
    (
        NamedListTag(ListTag([LongArrayTag([])], 12), ""),
        b"\t\x00\x00\x0c\x00\x00\x00\x01\x00\x00\x00\x00",
        b"\t\x00\x00\x0c\x01\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0a```\x04b\x06\x00Z&(=\x0c\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0ad\x80\x00\x00t\x0f\xe2\xcc\x0c\x00\x00\x00",
        "[[L;]]",
    ),
    (
        NamedListTag(ListTag([LongArrayTag([5, 6, 7])], 12), ""),
        b"\t\x00\x00\x0c\x00\x00\x00\x01\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07",
        b"\t\x00\x00\x0c\x01\x00\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0a```\x04bf\x06\x08`\x85\xd2lP\x9a\x1d\x00\xa9zsw$\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0ad```\x06bV\x06\x08`\x83\xd2\xecP\x1a\x00s\x8c:z$\x00\x00\x00",
        "[[L;5L, 6L, 7L]]",
    ),
    (
        NamedListTag(ListTag([LongArrayTag([-5, -6, -7])], 12), ""),
        b"\t\x00\x00\x0c\x00\x00\x00\x01\x00\x00\x00\x03\xff\xff\xff\xff\xff\xff\xff\xfb\xff\xff\xff\xff\xff\xff\xff\xfa\xff\xff\xff\xff\xff\xff\xff\xf9",
        b"\t\x00\x00\x0c\x01\x00\x00\x00\x03\x00\x00\x00\xfb\xff\xff\xff\xff\xff\xff\xff\xfa\xff\xff\xff\xff\xff\xff\xff\xf9\xff\xff\xff\xff\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0a```\x04b\xe6\xff\x10\xf0\x1bJ\xff\x82\xd2?\x01[aC\xc1$\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0ad```\x06\xe2\xdf\xff!\xe0\x17\x94\xfe\t\xa5\x01\xda\x81aa$\x00\x00\x00",
        "[[L;-5L, -6L, -7L]]",
    ),
    (
        NamedListTag(ListTag([StringTag("value")], 8), ""),
        b"\t\x00\x00\x08\x00\x00\x00\x01\x00\x05value",
        b"\t\x00\x00\x08\x01\x00\x00\x00\x05\x00value",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0````d`-K\xcc)M\x05\x00r\\\x9f\xe0\x0f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0`d```e(K\xcc)M\x05\x008=N\xef\x0f\x00\x00\x00",
        '["value"]',
    ),
    (
        NamedListTag(ListTag([ListTag([], 1)], 9), ""),
        b"\t\x00\x00\t\x00\x00\x00\x01\x01\x00\x00\x00\x00",
        b"\t\x00\x00\t\x01\x00\x00\x00\x01\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0d```d\x04\x12\x0c\x00\xb5\x9d\xc8\x82\r\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0dd``\x00a\x06\x00SZ\xef^\r\x00\x00\x00",
        "[[]]",
    ),
    (
        NamedListTag(ListTag([CompoundTag({})], 10), ""),
        b"\t\x00\x00\n\x00\x00\x00\x01\x00",
        b"\t\x00\x00\n\x01\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0b```d\x00\x00\xd2\xb0*\xf2\t\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xe0bd\x00\x02\x00#\xa8Q\xd6\t\x00\x00\x00",
        "[{}]",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ByteTag(5)}), ""),
        b"\n\x00\x00\x01\x00\x03key\x05\x00",
        b"\n\x00\x00\x01\x03\x00key\x05\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``d`\xceN\xadde\x00\x00\xaf}[\x07\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``df\xc8N\xadde\x00\x00\x9c\x15'\xb0\x0b\x00\x00\x00",
        "{key: 5b}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ByteTag(-5)}), ""),
        b"\n\x00\x00\x01\x00\x03key\xfb\x00",
        b"\n\x00\x00\x01\x03\x00key\xfb\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``d`\xceN\xad\xfc\xcd\x00\x00\x9c\xb1d\x8d\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``df\xc8N\xad\xfc\xcd\x00\x00\xaf\xd9\x18:\x0b\x00\x00\x00",
        "{key: -5b}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ShortTag(5)}), ""),
        b"\n\x00\x00\x02\x00\x03key\x00\x05\x00",
        b"\n\x00\x00\x02\x03\x00key\x05\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``b`\xceN\xadd`e\x00\x00\xe2\x00]\xd6\x0c\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``bf\xc8N\xadde`\x00\x002+\x86\x12\x0c\x00\x00\x00",
        "{key: 5s}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ShortTag(-5)}), ""),
        b"\n\x00\x00\x02\x00\x03key\xff\xfb\x00",
        b"\n\x00\x00\x02\x03\x00key\xfb\xff\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``b`\xceN\xad\xfc\xff\x9b\x01\x00<\xf8\xfa\xe2\x0c\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``bf\xc8N\xad\xfc\xfd\x9f\x01\x00\x9a\x88\xf8>\x0c\x00\x00\x00",
        "{key: -5s}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": IntTag(5)}), ""),
        b"\n\x00\x00\x03\x00\x03key\x00\x00\x00\x05\x00",
        b"\n\x00\x00\x03\x03\x00key\x05\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``f`\xceN\xadd```e\x00\x00{\x8e\xb6\xa6\x0e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``ff\xc8N\xadde\x00\x02\x00\x88r\x9b\xc1\x0e\x00\x00\x00",
        "{key: 5}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": IntTag(-5)}), ""),
        b"\n\x00\x00\x03\x00\x03key\xff\xff\xff\xfb\x00",
        b"\n\x00\x00\x03\x03\x00key\xfb\xff\xff\xff\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``f`\xceN\xad\xfc\xff\xff\xffo\x06\x00\xd8\xb7p\x86\x0e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``ff\xc8N\xad\xfc\xfd\xff\xff\x7f\x06\x00\xdaS&\xc5\x0e\x00\x00\x00",
        "{key: -5}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": LongTag(5)}), ""),
        b"\n\x00\x00\x04\x00\x03key\x00\x00\x00\x00\x00\x00\x00\x05\x00",
        b"\n\x00\x00\x04\x03\x00key\x05\x00\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``a`\xceN\xadd\x80\x00V\x06\x00\x04\xab@M\x12\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``af\xc8N\xadde\x80\x02\x00\x1bS\x0b\xbb\x12\x00\x00\x00",
        "{key: 5L}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": LongTag(-5)}), ""),
        b"\n\x00\x00\x04\x00\x03key\xff\xff\xff\xff\xff\xff\xff\xfb\x00",
        b"\n\x00\x00\x04\x03\x00key\xfb\xff\xff\xff\xff\xff\xff\xff\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``a`\xceN\xad\xfc\x0f\x01\xbf\x19\x00\xf6ypt\x12\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``af\xc8N\xad\xfc\xfd\x1f\x02\x18\x00\xeb\xa4[\x8c\x12\x00\x00\x00",
        "{key: -5L}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": FloatTag(5.0)}), ""),
        b"\n\x00\x00\x05\x00\x03key@\xa0\x00\x00\x00",
        b"\n\x00\x00\x05\x03\x00key\x00\x00\xa0@\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``e`\xceN\xadtX\xc0\xc0\xc0\x00\x001\xf1\xec&\x0e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``ef\xc8N\xadd`X\xe0\xc0\x00\x00\xde%\xcf\xc8\x0e\x00\x00\x00",
        "{key: 5.0f}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": FloatTag(-5.0)}), ""),
        b"\n\x00\x00\x05\x00\x03key\xc0\xa0\x00\x00\x00",
        b"\n\x00\x00\x05\x03\x00key\x00\x00\xa0\xc0\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``e`\xceN\xad<\xb0\x80\x81\x81\x01\x00\xa3A\n\x97\x0e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``ef\xc8N\xadd`Xp\x80\x01\x00\x95\xbdL\xf3\x0e\x00\x00\x00",
        "{key: -5.0f}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": DoubleTag(5.0)}), ""),
        b"\n\x00\x00\x06\x00\x03key@\x14\x00\x00\x00\x00\x00\x00\x00",
        b"\n\x00\x00\x06\x03\x00key\x00\x00\x00\x00\x00\x00\x14@\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``c`\xceN\xadt\x10a\x80\x00\x00\x06\xd2\xd2\xbe\x12\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``cf\xc8N\xadd\x00\x03\x11\x07\x06\x00l\xe3L\xb2\x12\x00\x00\x00",
        "{key: 5.0d}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": DoubleTag(-5.0)}), ""),
        b"\n\x00\x00\x06\x00\x03key\xc0\x14\x00\x00\x00\x00\x00\x00\x00",
        b"\n\x00\x00\x06\x03\x00key\x00\x00\x00\x00\x00\x00\x14\xc0\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``c`\xceN\xad< \xc2\x00\x01\x00I\xd2\x87\xd8\x12\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``cf\xc8N\xadd\x00\x03\x91\x03\x0c\x00'{\xcf\x89\x12\x00\x00\x00",
        "{key: -5.0d}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ByteArrayTag([])}), ""),
        b"\n\x00\x00\x07\x00\x03key\x00\x00\x00\x00\x00",
        b"\n\x00\x00\x07\x03\x00key\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``g`\xceN\xadd\x00\x01\x00\xbc\t\x18k\x0e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``gf\xc8N\xadd\x00\x01\x00z\x8e\xa2\xb9\x0e\x00\x00\x00",
        "{key: [B;]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ByteArrayTag([5, 6, 7])}), ""),
        b"\n\x00\x00\x07\x00\x03key\x00\x00\x00\x03\x05\x06\x07\x00",
        b"\n\x00\x00\x07\x03\x00key\x03\x00\x00\x00\x05\x06\x07\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``g`\xceN\xadd```fecg\x00\x00\x85\x9d\x19\xca\x11\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``gf\xc8N\xaddf```ecg\x00\x00\x88^b\xc9\x11\x00\x00\x00",
        "{key: [B;5B, 6B, 7B]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ByteArrayTag([-5, -6, -7])}), ""),
        b"\n\x00\x00\x07\x00\x03key\x00\x00\x00\x03\xfb\xfa\xf9\x00",
        b"\n\x00\x00\x07\x03\x00key\x03\x00\x00\x00\xfb\xfa\xf9\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``g`\xceN\xadd```\xfe\xfd\xeb'\x03\x00\x96\xbaA\x9a\x11\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b``gf\xc8N\xaddf``\xf8\xfd\xeb'\x03\x00\x9by:\x99\x11\x00\x00\x00",
        "{key: [B;-5B, -6B, -7B]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": IntArrayTag([])}), ""),
        b"\n\x00\x00\x0b\x00\x03key\x00\x00\x00\x00\x00",
        b"\n\x00\x00\x0b\x03\x00key\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0f`\xceN\xadd\x00\x01\x00{\x9b\x02a\x0e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0ff\xc8N\xadd\x00\x01\x00\xbd\x1c\xb8\xb3\x0e\x00\x00\x00",
        "{key: [I;]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": IntArrayTag([5, 6, 7])}), ""),
        b"\n\x00\x00\x0b\x00\x03key\x00\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x06\x00\x00\x00\x07\x00",
        b"\n\x00\x00\x0b\x03\x00key\x03\x00\x00\x00\x05\x00\x00\x00\x06\x00\x00\x00\x07\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0f`\xceN\xadd```\x06bV f\x03bv\x06\x00\x1aK\x86\x98\x1a\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0ff\xc8N\xaddf```\x05b6 f\x07b\x06\x00\xf1\xb2?V\x1a\x00\x00\x00",
        "{key: [I;5, 6, 7]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": IntArrayTag([-5, -6, -7])}), ""),
        b"\n\x00\x00\x0b\x00\x03key\x00\x00\x00\x03\xff\xff\xff\xfb\xff\xff\xff\xfa\xff\xff\xff\xf9\x00",
        b"\n\x00\x00\x0b\x03\x00key\x03\x00\x00\x00\xfb\xff\xff\xff\xfa\xff\xff\xff\xf9\xff\xff\xff\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0f`\xceN\xadd```\xfe\xff\xff\xffo \xfe\x05\xc4?\x19\x00\x059k8\x1a\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0ff\xc8N\xaddf``\xf8\xfd\xff\xff\xff_@\xfc\x13\x88\x19\x00\xcf$\xe4_\x1a\x00\x00\x00",
        "{key: [I;-5, -6, -7]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": LongArrayTag([])}), ""),
        b"\n\x00\x00\x0c\x00\x03key\x00\x00\x00\x00\x00",
        b"\n\x00\x00\x0c\x03\x00key\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0a`\xceN\xadd\x00\x01\x00\xf8\x8e9H\x0e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0af\xc8N\xadd\x00\x01\x00>\t\x83\x9a\x0e\x00\x00\x00",
        "{key: [L;]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": LongArrayTag([5, 6, 7])}), ""),
        b"\n\x00\x00\x0c\x00\x03key\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07\x00",
        b"\n\x00\x00\x0c\x03\x00key\x03\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0a`\xceN\xadd```f\x80\x00V(\xcd\x06\xa5\xd9\x19\x00`\xcf\x11w&\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0af\xc8N\xaddf```e\x80\x006(\xcd\x0e\xa5\x19\x00\xe8\x8c\x19-&\x00\x00\x00",
        "{key: [L;5L, 6L, 7L]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": LongArrayTag([-5, -6, -7])}), ""),
        b"\n\x00\x00\x0c\x00\x03key\x00\x00\x00\x03\xff\xff\xff\xff\xff\xff\xff\xfb\xff\xff\xff\xff\xff\xff\xff\xfa\xff\xff\xff\xff\xff\xff\xff\xf9\x00",
        b"\n\x00\x00\x0c\x03\x00key\x03\x00\x00\x00\xfb\xff\xff\xff\xff\xff\xff\xff\xfa\xff\xff\xff\xff\xff\xff\xff\xf9\xff\xff\xff\xff\xff\xff\xff\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0a`\xceN\xadd```\xfe\x0f\x01\xbf\xa1\xf4/(\xfd\x93\x01\x00Kl\x14$&\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0af\xc8N\xaddf``\xf8\xfd\x1f\x02~A\xe9\x9fP\x9a\x01\x00\xa9\xcc\x08\x82&\x00\x00\x00",
        "{key: [L;-5L, -6L, -7L]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": StringTag("value")}), ""),
        b"\n\x00\x00\x08\x00\x03key\x00\x05value\x00",
        b"\n\x00\x00\x08\x03\x00key\x05\x00value\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0``\xceN\xadd`-K\xcc)Me\x00\x00\x80\xabn\xb7\x11\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0`f\xc8N\xadde(K\xcc)Me\x00\x00}4\xe2g\x11\x00\x00\x00",
        '{key: "value"}',
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ListTag([], 1)}), ""),
        b"\n\x00\x00\t\x00\x03key\x01\x00\x00\x00\x00\x00",
        b"\n\x00\x00\t\x03\x00key\x01\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0d`\xceN\xaddd\x00\x01\x00\x98\x08\xd32\x0f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0df\xc8N\xaddd\x00\x01\x00\x9a\xd5\x06@\x0f\x00\x00\x00",
        "{key: []}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": CompoundTag({})}), ""),
        b"\n\x00\x00\n\x00\x03key\x00\x00",
        b"\n\x00\x00\n\x03\x00key\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0b`\xceN\xadd`\x00\x00\xbc\x95F'\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xe0bf\xc8N\xadd`\x00\x00\x8f\xfd:\x90\x0b\x00\x00\x00",
        "{key: {}}",
    ),
    (
        NamedByteTag(ByteTag(5), "name"),
        b"\x01\x00\x04name\x05",
        b"\x01\x04\x00name\x05",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcd`\xc9K\xccMe\x05\x00\xb5\xf7n\xbf\x08\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcda\xc8K\xccMe\x05\x00\xb0\x91\xb0\xd0\x08\x00\x00\x00",
        "5b",
    ),
    (
        NamedByteTag(ByteTag(-5), "name"),
        b"\x01\x00\x04name\xfb",
        b"\x01\x04\x00name\xfb",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcd`\xc9K\xccM\xfd\r\x00\xae(k\xe5\x08\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcda\xc8K\xccM\xfd\r\x00\xabN\xb5\x8a\x08\x00\x00\x00",
        "-5b",
    ),
    (
        NamedShortTag(ShortTag(5), "name"),
        b"\x02\x00\x04name\x00\x05",
        b"\x02\x04\x00name\x05\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcb`\xc9K\xccMe`\x05\x00v\xfa&]\t\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcba\xc8K\xccMee\x00\x00U\xd0> \t\x00\x00\x00",
        "5s",
    ),
    (
        NamedShortTag(ShortTag(-5), "name"),
        b"\x02\x00\x04name\xff\xfb",
        b"\x02\x04\x00name\xfb\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcb`\xc9K\xccM\xfd\xff\x1b\x00\x1f\xd8\x07\x94\t\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcba\xc8K\xccM\xfd\xfd\x1f\x00\xeb\xf3\x03\x87\t\x00\x00\x00",
        "-5s",
    ),
    (
        NamedIntTag(IntTag(5), "name"),
        b"\x03\x00\x04name\x00\x00\x00\x05",
        b"\x03\x04\x00name\x05\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcf`\xc9K\xccMe```\x05\x00\x0fc\xfb\xd2\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcfa\xc8K\xccMee``\x00\x00\xc4\x96H\xc1\x0b\x00\x00\x00",
        "5",
    ),
    (
        NamedIntTag(IntTag(-5), "name"),
        b"\x03\x00\x04name\xff\xff\xff\xfb",
        b"\x03\x04\x00name\xfb\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcf`\xc9K\xccM\xfd\xff\xff\xffo\x00zsG{\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcfa\xc8K\xccM\xfd\xfd\xff\xff\x7f\x00B\xd1O\xa7\x0b\x00\x00\x00",
        "-5",
    ),
    (
        NamedLongTag(LongTag(5), "name"),
        b"\x04\x00\x04name\x00\x00\x00\x00\x00\x00\x00\x05",
        b"\x04\x04\x00name\x05\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffca`\xc9K\xccMe\x80\x00V\x00XE\xa8\x8f\x0f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcaa\xc8K\xccMee\x80\x00\x00>Z7n\x0f\x00\x00\x00",
        "5L",
    ),
    (
        NamedLongTag(LongTag(-5), "name"),
        b"\x04\x00\x04name\xff\xff\xff\xff\xff\xff\xff\xfb",
        b"\x04\x04\x00name\xfb\xff\xff\xff\xff\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffca`\xc9K\xccM\xfd\x0f\x01\xbf\x01\xbbu\xc9\xbc\x0f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcaa\xc8K\xccM\xfd\xfd\x1f\x02\x00\xd5Z\xfb\xe6\x0f\x00\x00\x00",
        "-5L",
    ),
    (
        NamedFloatTag(FloatTag(5.0), "name"),
        b"\x05\x00\x04name@\xa0\x00\x00",
        b"\x05\x04\x00name\x00\x00\xa0@",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffce`\xc9K\xccMuX\xc0\xc0\x00\x00\x9eXH\x08\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcea\xc8K\xccMe`X\xe0\x00\x00\xccQ\xf8\xc6\x0b\x00\x00\x00",
        "5.0f",
    ),
    (
        NamedFloatTag(FloatTag(-5.0), "name"),
        b"\x05\x00\x04name\xc0\xa0\x00\x00",
        b"\x05\x04\x00name\x00\x00\xa0\xc0",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffce`\xc9K\xccM=\xb0\x80\x81\x01\x00\xa5\xee\x11\xe5\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcea\xc8K\xccMe`Xp\x00\x00\xec\xd2@+\x0b\x00\x00\x00",
        "-5.0f",
    ),
    (
        NamedDoubleTag(DoubleTag(5.0), "name"),
        b"\x06\x00\x04name@\x14\x00\x00\x00\x00\x00\x00",
        b"\x06\x04\x00name\x00\x00\x00\x00\x00\x00\x14@",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcc`\xc9K\xccMu\x10a\x00\x03\x00vzH\xed\x0f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcca\xc8K\xccMe\x00\x03\x11\x07\x00\x0es#\xd6\x0f\x00\x00\x00",
        "5.0d",
    ),
    (
        NamedDoubleTag(DoubleTag(-5.0), "name"),
        b"\x06\x00\x04name\xc0\x14\x00\x00\x00\x00\x00\x00",
        b"\x06\x04\x00name\x00\x00\x00\x00\x00\x00\x14\xc0",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcc`\xc9K\xccM= \xc2\x00\x06\x00\xac\xffs\xbe\x0f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcca\xc8K\xccMe\x00\x03\x91\x03\x00.\xf0\x9b;\x0f\x00\x00\x00",
        "-5.0d",
    ),
    (
        NamedByteArrayTag(ByteArrayTag([]), "name"),
        b"\x07\x00\x04name\x00\x00\x00\x00",
        b"\x07\x04\x00name\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcg`\xc9K\xccMe\x00\x02\x00\x02\xe4H\x12\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcga\xc8K\xccMe\x00\x02\x00t\x15OF\x0b\x00\x00\x00",
        "[B;]",
    ),
    (
        NamedByteArrayTag(ByteArrayTag([5, 6, 7]), "name"),
        b"\x07\x00\x04name\x00\x00\x00\x03\x05\x06\x07",
        b"\x07\x04\x00name\x03\x00\x00\x00\x05\x06\x07",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcg`\xc9K\xccMe```fec\x07\x00\x04\xad\x90b\x0e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcga\xc8K\xccMef```ec\x07\x00\x9eIr\x82\x0e\x00\x00\x00",
        "[B;5B, 6B, 7B]",
    ),
    (
        NamedByteArrayTag(ByteArrayTag([-5, -6, -7]), "name"),
        b"\x07\x00\x04name\x00\x00\x00\x03\xfb\xfa\xf9",
        b"\x07\x04\x00name\x03\x00\x00\x00\xfb\xfa\xf9",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcg`\xc9K\xccMe```\xfe\xfd\xeb'\x00t\x82\xc6?\x0e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xffcga\xc8K\xccMef``\xf8\xfd\xeb'\x00\xeef$\xdf\x0e\x00\x00\x00",
        "[B;-5B, -6B, -7B]",
    ),
    (
        NamedIntArrayTag(IntArrayTag([]), "name"),
        b"\x0b\x00\x04name\x00\x00\x00\x00",
        b"\x0b\x04\x00name\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3f`\xc9K\xccMe\x00\x02\x00\xc5vR\x18\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3fa\xc8K\xccMe\x00\x02\x00\xb3\x87UL\x0b\x00\x00\x00",
        "[I;]",
    ),
    (
        NamedIntArrayTag(IntArrayTag([5, 6, 7]), "name"),
        b"\x0b\x00\x04name\x00\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x06\x00\x00\x00\x07",
        b"\x0b\x04\x00name\x03\x00\x00\x00\x05\x00\x00\x00\x06\x00\x00\x00\x07\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3f`\xc9K\xccMe```\x06bV f\x03bv\x00A\x0e\xc5\xe9\x17\x00\x00\x00",
        b'\x1f\x8b\x08\x00)\x83va\x02\xff\xe3fa\xc8K\xccMef```\x05b6 f\x07b\x00\xa4"7\xab\x17\x00\x00\x00',
        "[I;5, 6, 7]",
    ),
    (
        NamedIntArrayTag(IntArrayTag([-5, -6, -7]), "name"),
        b"\x0b\x00\x04name\x00\x00\x00\x03\xff\xff\xff\xfb\xff\xff\xff\xfa\xff\xff\xff\xf9",
        b"\x0b\x04\x00name\x03\x00\x00\x00\xfb\xff\xff\xff\xfa\xff\xff\xff\xf9\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3f`\xc9K\xccMe```\xfe\xff\xff\xffo \xfe\x05\xc4?\x01\xa1iU\x0e\x17\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3fa\xc8K\xccMef``\xf8\xfd\xff\xff\xff_@\xfc\x13\x88\x01\xa87\xed\xc6\x17\x00\x00\x00",
        "[I;-5, -6, -7]",
    ),
    (
        NamedLongArrayTag(LongArrayTag([]), "name"),
        b"\x0c\x00\x04name\x00\x00\x00\x00",
        b"\x0c\x04\x00name\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3a`\xc9K\xccMe\x00\x02\x00Fci1\x0b\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3aa\xc8K\xccMe\x00\x02\x000\x92ne\x0b\x00\x00\x00",
        "[L;]",
    ),
    (
        NamedLongArrayTag(LongArrayTag([5, 6, 7]), "name"),
        b"\x0c\x00\x04name\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07",
        b"\x0c\x04\x00name\x03\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3a`\xc9K\xccMe```f\x80\x00V(\xcd\x06\xa5\xd9\x01\xc8\xbf\x9b\xc7#\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3aa\xc8K\xccMef```e\x80\x006(\xcd\x0e\xa5\x01\x88\x92\xcc\x11#\x00\x00\x00",
        "[L;5L, 6L, 7L]",
    ),
    (
        NamedLongArrayTag(LongArrayTag([-5, -6, -7]), "name"),
        b"\x0c\x00\x04name\x00\x00\x00\x03\xff\xff\xff\xff\xff\xff\xff\xfb\xff\xff\xff\xff\xff\xff\xff\xfa\xff\xff\xff\xff\xff\xff\xff\xf9",
        b"\x0c\x04\x00name\x03\x00\x00\x00\xfb\xff\xff\xff\xff\xff\xff\xff\xfa\xff\xff\xff\xff\xff\xff\xff\xf9\xff\xff\xff\xff\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3a`\xc9K\xccMe```\xfe\x0f\x01\xbf\xa1\xf4/(\xfd\x13\x00:\xa4\xabq#\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3aa\xc8K\xccMef``\xf8\xfd\x1f\x02~A\xe9\x9fP\x1a\x00!\x9f\x97\n#\x00\x00\x00",
        "[L;-5L, -6L, -7L]",
    ),
    (
        NamedStringTag(StringTag("value"), "name"),
        b"\x08\x00\x04name\x00\x05value",
        b"\x08\x04\x00name\x05\x00value",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3``\xc9K\xccMe`-K\xcc)M\x05\x00Hx\xdcc\x0e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3`a\xc8K\xccMee(K\xcc)M\x05\x00\xb5\x97\x96\xa2\x0e\x00\x00\x00",
        '"value"',
    ),
    (
        NamedListTag(ListTag([], 1), "name"),
        b"\t\x00\x04name\x01\x00\x00\x00\x00",
        b"\t\x04\x00name\x01\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMed\x00\x02\x00\xeb<O\xe8\x0c\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMed\x00\x02\x00\x13\xef}Q\x0c\x00\x00\x00",
        "[]",
    ),
    (
        NamedCompoundTag(CompoundTag({}), "name"),
        b"\n\x00\x04name\x00",
        b"\n\x04\x00name\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMe\x00\x00l\x1fn\x92\x08\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMe\x00\x00iy\xb0\xfd\x08\x00\x00\x00",
        "{}",
    ),
    (
        NamedListTag(ListTag([ByteTag(5)], 1), "name"),
        b"\t\x00\x04name\x01\x00\x00\x00\x01\x05",
        b"\t\x04\x00name\x01\x01\x00\x00\x00\x05",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMed```d\x05\x00\x8f^C\x8c\r\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMedd```\x05\x00\x83\x0e\xe7\x1b\r\x00\x00\x00",
        "[5b]",
    ),
    (
        NamedListTag(ListTag([ByteTag(-5)], 1), "name"),
        b"\t\x00\x04name\x01\x00\x00\x00\x01\xfb",
        b"\t\x04\x00name\x01\x01\x00\x00\x00\xfb",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMed```\xfc\r\x00\x94\x81F\xd6\r\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMedd``\xf8\r\x00\x98\xd1\xe2A\r\x00\x00\x00",
        "[-5b]",
    ),
    (
        NamedListTag(ListTag([ShortTag(5)], 2), "name"),
        b"\t\x00\x04name\x02\x00\x00\x00\x01\x00\x05",
        b"\t\x04\x00name\x02\x01\x00\x00\x00\x05\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMeb```d`\x05\x005(|\x93\x0e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMebd```e\x00\x00\x84\xc0@\x97\x0e\x00\x00\x00",
        "[5s]",
    ),
    (
        NamedListTag(ListTag([ShortTag(-5)], 2), "name"),
        b"\t\x00\x04name\x02\x00\x00\x00\x01\xff\xfb",
        b"\t\x04\x00name\x02\x01\x00\x00\x00\xfb\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMeb```\xfc\xff\x1b\x00\\\n]Z\x0e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMebd``\xf8\xfd\x1f\x00:\xe3}0\x0e\x00\x00\x00",
        "[-5s]",
    ),
    (
        NamedListTag(ListTag([IntTag(5)], 3), "name"),
        b"\t\x00\x04name\x03\x00\x00\x00\x01\x00\x00\x00\x05",
        b"\t\x04\x00name\x03\x01\x00\x00\x00\x05\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMef```\x04bV\x00\xe8\xc9\x87\xb7\x10\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMefd```\x05b\x00\x03\x0e)\x92\x10\x00\x00\x00",
        "[5]",
    ),
    (
        NamedListTag(ListTag([IntTag(-5)], 3), "name"),
        b"\t\x00\x04name\x03\x00\x00\x00\x01\xff\xff\xff\xfb",
        b"\t\x04\x00name\x03\x01\x00\x00\x00\xfb\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMef```\xfc\xff\xff\xffo\x00\x9d\xd9;\x1e\x10\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMefd``\xf8\xfd\xff\xff\x7f\x00\x85I.\xf4\x10\x00\x00\x00",
        "[-5]",
    ),
    (
        NamedListTag(ListTag([LongTag(5)], 4), "name"),
        b"\t\x00\x04name\x04\x00\x00\x00\x01\x00\x00\x00\x00\x00\x00\x00\x05",
        b"\t\x04\x00name\x04\x01\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMea```d\x80\x00V\x00\x00N\xcfH\x14\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMead```e\x80\x00\x00#6[\x1e\x14\x00\x00\x00",
        "[5L]",
    ),
    (
        NamedListTag(ListTag([LongTag(-5)], 4), "name"),
        b"\t\x00\x04name\x04\x00\x00\x00\x01\xff\xff\xff\xff\xff\xff\xff\xfb",
        b"\t\x04\x00name\x04\x01\x00\x00\x00\xfb\xff\xff\xff\xff\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMea```\xfc\x0f\x01\xbf\x01\xe3~\xae{\x14\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMead``\xf8\xfd\x1f\x02\x00\xc86\x97\x96\x14\x00\x00\x00",
        "[-5L]",
    ),
    (
        NamedListTag(ListTag([FloatTag(5.0)], 5), "name"),
        b"\t\x00\x04name\x05\x00\x00\x00\x01@\xa0\x00\x00",
        b"\t\x04\x00name\x05\x01\x00\x00\x00\x00\x00\xa0@",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMee```tX\xc0\xc0\x00\x00\xb0A\x9b\xf6\x10\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMeed\x00\x81\x05\x0e\x00\xc2z6\x0e\x10\x00\x00\x00",
        "[5.0f]",
    ),
    (
        NamedListTag(ListTag([FloatTag(-5.0)], 5), "name"),
        b"\t\x00\x04name\x05\x00\x00\x00\x01\xc0\xa0\x00\x00",
        b"\t\x04\x00name\x05\x01\x00\x00\x00\x00\x00\xa0\xc0",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMee```<\xb0\x80\x81\x01\x00\x8b\xf7\xc2\x1b\x10\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMeed\x00\x81\x05\x07\x00\xe2\xf9\x8e\xe3\x10\x00\x00\x00",
        "[-5.0f]",
    ),
    (
        NamedListTag(ListTag([DoubleTag(5.0)], 6), "name"),
        b"\t\x00\x04name\x06\x00\x00\x00\x01@\x14\x00\x00\x00\x00\x00\x00",
        b"\t\x04\x00name\x06\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x14@",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMec```t\x10a\x00\x03\x00\xf4u\xf5\xe2\x14\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMecd\x80\x01\x11\x07\x00\xc9\x1b\x95n\x14\x00\x00\x00",
        "[5.0d]",
    ),
    (
        NamedListTag(ListTag([DoubleTag(-5.0)], 6), "name"),
        b"\t\x00\x04name\x06\x00\x00\x00\x01\xc0\x14\x00\x00\x00\x00\x00\x00",
        b"\t\x04\x00name\x06\x01\x00\x00\x00\x00\x00\x00\x00\x00\x00\x14\xc0",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMec```< \xc2\x00\x06\x00.\xf0\xce\xb1\x14\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMecd\x80\x01\x91\x03\x00\xe9\x98-\x83\x14\x00\x00\x00",
        "[-5.0d]",
    ),
    (
        NamedListTag(ListTag([ByteArrayTag([])], 7), "name"),
        b"\t\x00\x04name\x07\x00\x00\x00\x01\x00\x00\x00\x00",
        b"\t\x04\x00name\x07\x01\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMeg```\x04b\x06\x00kl\x01\x9a\x10\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMegd\x80\x00\x00=\xaf\x1b\xf8\x10\x00\x00\x00",
        "[[B;]]",
    ),
    (
        NamedListTag(ListTag([ByteArrayTag([5, 6, 7])], 7), "name"),
        b"\t\x00\x04name\x07\x00\x00\x00\x01\x00\x00\x00\x03\x05\x06\x07",
        b"\t\x04\x00name\x07\x01\x00\x00\x00\x03\x00\x00\x00\x05\x06\x07",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMeg```\x04bfV6v\x00T\xb6\xcc\xd9\x13\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMegd```\x06bV6v\x00\xb0,\x15\x8f\x13\x00\x00\x00",
        "[[B;5B, 6B, 7B]]",
    ),
    (
        NamedListTag(ListTag([ByteArrayTag([-5, -6, -7])], 7), "name"),
        b"\t\x00\x04name\x07\x00\x00\x00\x01\x00\x00\x00\x03\xfb\xfa\xf9",
        b"\t\x04\x00name\x07\x01\x00\x00\x00\x03\x00\x00\x00\xfb\xfa\xf9",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccMeg```\x04b\xe6\xdf\xbf~\x02\x00$\x99\x9a\x84\x13\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccMegd```\x06\xe2\xdf\xbf~\x02\x00\xc0\x03C\xd2\x13\x00\x00\x00",
        "[[B;-5B, -6B, -7B]]",
    ),
    (
        NamedListTag(ListTag([IntArrayTag([])], 11), "name"),
        b"\t\x00\x04name\x0b\x00\x00\x00\x01\x00\x00\x00\x00",
        b"\t\x04\x00name\x0b\x01\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccM\xe5f```\x04b\x06\x00\x7f\x9f5|\x10\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccM\xe5fd\x80\x00\x00)\\/\x1e\x10\x00\x00\x00",
        "[[I;]]",
    ),
    (
        NamedListTag(ListTag([IntArrayTag([5, 6, 7])], 11), "name"),
        b"\t\x00\x04name\x0b\x00\x00\x00\x01\x00\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x06\x00\x00\x00\x07",
        b"\t\x04\x00name\x0b\x01\x00\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x06\x00\x00\x00\x07\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccM\xe5f```\x04bf f\x05b6 f\x07\x00G\xed\xd0\x19\x1c\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccM\xe5fd```\x06bV f\x03bv \x06\x00\x87[n\xbc\x1c\x00\x00\x00",
        "[[I;5, 6, 7]]",
    ),
    (
        NamedListTag(ListTag([IntArrayTag([-5, -6, -7])], 11), "name"),
        b"\t\x00\x04name\x0b\x00\x00\x00\x01\x00\x00\x00\x03\xff\xff\xff\xfb\xff\xff\xff\xfa\xff\xff\xff\xf9",
        b"\t\x04\x00name\x0b\x01\x00\x00\x00\x03\x00\x00\x00\xfb\xff\xff\xff\xfa\xff\xff\xff\xf9\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccM\xe5f```\x04b\xe6\xff\xff\xff\xff\x06\xe2_@\xfc\x13\x00\xa7\x8a@\xfe\x1c\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccM\xe5fd```\x06\xe2\xdf\xff\xff\xff\xff\x05\xc4?\x81\x18\x00\x8bN\xb4\xd1\x1c\x00\x00\x00",
        "[[I;-5, -6, -7]]",
    ),
    (
        NamedListTag(ListTag([LongArrayTag([])], 12), "name"),
        b"\t\x00\x04name\x0c\x00\x00\x00\x01\x00\x00\x00\x00",
        b"\t\x04\x00name\x0c\x01\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccM\xe5a```\x04b\x06\x00\xb6\xf2T\x18\x10\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccM\xe5ad\x80\x00\x00\xe01Nz\x10\x00\x00\x00",
        "[[L;]]",
    ),
    (
        NamedListTag(ListTag([LongArrayTag([5, 6, 7])], 12), "name"),
        b"\t\x00\x04name\x0c\x00\x00\x00\x01\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07",
        b"\t\x04\x00name\x0c\x01\x00\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccM\xe5a```\x04bf\x06\x08`\x85\xd2lP\x9a\x1d\x00\xda\xc9\x94B(\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccM\xe5ad```\x06bV\x06\x08`\x83\xd2\xecP\x1a\x00\xae\xea8\xf5(\x00\x00\x00",
        "[[L;5L, 6L, 7L]]",
    ),
    (
        NamedListTag(ListTag([LongArrayTag([-5, -6, -7])], 12), "name"),
        b"\t\x00\x04name\x0c\x00\x00\x00\x01\x00\x00\x00\x03\xff\xff\xff\xff\xff\xff\xff\xfb\xff\xff\xff\xff\xff\xff\xff\xfa\xff\xff\xff\xff\xff\xff\xff\xf9",
        b"\t\x04\x00name\x0c\x01\x00\x00\x00\x03\x00\x00\x00\xfb\xff\xff\xff\xff\xff\xff\xff\xfa\xff\xff\xff\xff\xff\xff\xff\xf9\xff\xff\xff\xff\xff\xff\xff",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccM\xe5a```\x04b\xe6\xff\x10\xf0\x1bJ\xff\x82\xd2?\x01(\xd2\xa4\xf4(\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccM\xe5ad```\x06\xe2\xdf\xff!\xe0\x17\x94\xfe\t\xa5\x01\x07\xe7c\xee(\x00\x00\x00",
        "[[L;-5L, -6L, -7L]]",
    ),
    (
        NamedListTag(ListTag([StringTag("value")], 8), "name"),
        b"\t\x00\x04name\x08\x00\x00\x00\x01\x00\x05value",
        b"\t\x04\x00name\x08\x01\x00\x00\x00\x05\x00value",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccM\xe5````d`-K\xcc)M\x05\x00\x9fH\x80\xfc\x13\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccM\xe5`d```e(K\xcc)M\x05\x00\x1c\xd9\xf1\x8b\x13\x00\x00\x00",
        '["value"]',
    ),
    (
        NamedListTag(ListTag([ListTag([], 1)], 9), "name"),
        b"\t\x00\x04name\t\x00\x00\x00\x01\x01\x00\x00\x00\x00",
        b"\t\x04\x00name\t\x01\x00\x00\x00\x01\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccM\xe5d```d\x04\x12\x0c\x002OQ+\x11\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccM\xe5dd``\x00a\x06\x000\xa1;\xa9\x11\x00\x00\x00",
        "[[]]",
    ),
    (
        NamedListTag(ListTag([CompoundTag({})], 10), "name"),
        b"\t\x00\x04name\n\x00\x00\x00\x01\x00",
        b"\t\x04\x00name\n\x01\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3d`\xc9K\xccM\xe5b```d\x00\x00\xc3Z\xee\x96\r\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3da\xc8K\xccM\xe5bd\x00\x02\x00\xcf\nJ\x01\r\x00\x00\x00",
        "[{}]",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ByteTag(5)}), "name"),
        b"\n\x00\x04name\x01\x00\x03key\x05\x00",
        b"\n\x04\x00name\x01\x03\x00key\x05\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMed`\xceN\xadde\x00\x00e=\xc2\x9c\x0f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMedf\xc8N\xadde\x00\x00\xdb\xb0\xab\xf2\x0f\x00\x00\x00",
        "{key: 5b}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ByteTag(-5)}), "name"),
        b"\n\x00\x04name\x01\x00\x03key\xfb\x00",
        b"\n\x04\x00name\x01\x03\x00key\xfb\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMed`\xceN\xad\xfc\xcd\x00\x00V\xf1\xfd\x16\x0f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMedf\xc8N\xad\xfc\xcd\x00\x00\xe8|\x94x\x0f\x00\x00\x00",
        "{key: -5b}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ShortTag(5)}), "name"),
        b"\n\x00\x04name\x02\x00\x03key\x00\x05\x00",
        b"\n\x04\x00name\x02\x03\x00key\x05\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMeb`\xceN\xadd`e\x00\x00\x0c\xb2w\xad\x10\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMebf\xc8N\xadde`\x00\x00\xa4s|\xfa\x10\x00\x00\x00",
        "{key: 5s}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ShortTag(-5)}), "name"),
        b"\n\x00\x04name\x02\x00\x03key\xff\xfb\x00",
        b"\n\x04\x00name\x02\x03\x00key\xfb\xff\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMeb`\xceN\xad\xfc\xff\x9b\x01\x00\xd2J\xd0\x99\x10\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMebf\xc8N\xad\xfc\xfd\x9f\x01\x00\x0c\xd0\x02\xd6\x10\x00\x00\x00",
        "{key: -5s}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": IntTag(5)}), "name"),
        b"\n\x00\x04name\x03\x00\x03key\x00\x00\x00\x05\x00",
        b"\n\x04\x00name\x03\x03\x00key\x05\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMef`\xceN\xadd```e\x00\x00\x93\xf9$C\x12\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMeff\xc8N\xadde\x00\x02\x00(n0\x83\x12\x00\x00\x00",
        "{key: 5}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": IntTag(-5)}), "name"),
        b"\n\x00\x04name\x03\x00\x03key\xff\xff\xff\xfb\x00",
        b"\n\x04\x00name\x03\x03\x00key\xfb\xff\xff\xff\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMef`\xceN\xad\xfc\xff\xff\xffo\x06\x000\xc0\xe2c\x12\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMeff\xc8N\xad\xfc\xfd\xff\xff\x7f\x06\x00zO\x8d\x87\x12\x00\x00\x00",
        "{key: -5}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": LongTag(5)}), "name"),
        b"\n\x00\x04name\x04\x00\x03key\x00\x00\x00\x00\x00\x00\x00\x05\x00",
        b"\n\x04\x00name\x04\x03\x00key\x05\x00\x00\x00\x00\x00\x00\x00\x00",
        b'\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMea`\xceN\xadd\x80\x00V\x06\x00iB"\x9c\x16\x00\x00\x00',
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMeaf\xc8N\xadde\x80\x02\x00\x94U}6\x16\x00\x00\x00",
        "{key: 5L}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": LongTag(-5)}), "name"),
        b"\n\x00\x04name\x04\x00\x03key\xff\xff\xff\xff\xff\xff\xff\xfb\x00",
        b"\n\x04\x00name\x04\x03\x00key\xfb\xff\xff\xff\xff\xff\xff\xff\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMea`\xceN\xad\xfc\x0f\x01\xbf\x19\x00\x9b\x90\x12\xa5\x16\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMeaf\xc8N\xad\xfc\xfd\x1f\x02\x18\x00d\xa2-\x01\x16\x00\x00\x00",
        "{key: -5L}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": FloatTag(5.0)}), "name"),
        b"\n\x00\x04name\x05\x00\x03key@\xa0\x00\x00\x00",
        b"\n\x04\x00name\x05\x03\x00key\x00\x00\xa0@\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMee`\xceN\xadtX\xc0\xc0\xc0\x00\x00\xd9\x86~\xc3\x12\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMeef\xc8N\xadd`X\xe0\xc0\x00\x00~9d\x8a\x12\x00\x00\x00",
        "{key: 5.0f}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": FloatTag(-5.0)}), "name"),
        b"\n\x00\x04name\x05\x00\x03key\xc0\xa0\x00\x00\x00",
        b"\n\x04\x00name\x05\x03\x00key\x00\x00\xa0\xc0\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMee`\xceN\xad<\xb0\x80\x81\x81\x01\x00K6\x98r\x12\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMeef\xc8N\xadd`Xp\x80\x01\x005\xa1\xe7\xb1\x12\x00\x00\x00",
        "{key: -5.0f}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": DoubleTag(5.0)}), "name"),
        b"\n\x00\x04name\x06\x00\x03key@\x14\x00\x00\x00\x00\x00\x00\x00",
        b"\n\x04\x00name\x06\x03\x00key\x00\x00\x00\x00\x00\x00\x14@\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMec`\xceN\xadt\x10a\x80\x00\x00k;\xb0o\x16\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMecf\xc8N\xadd\x00\x03\x11\x07\x06\x00\xe3\xe5:?\x16\x00\x00\x00",
        "{key: 5.0d}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": DoubleTag(-5.0)}), "name"),
        b"\n\x00\x04name\x06\x00\x03key\xc0\x14\x00\x00\x00\x00\x00\x00\x00",
        b"\n\x04\x00name\x06\x03\x00key\x00\x00\x00\x00\x00\x00\x14\xc0\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMec`\xceN\xad< \xc2\x00\x01\x00$;\xe5\t\x16\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMecf\xc8N\xadd\x00\x03\x91\x03\x0c\x00\xa8}\xb9\x04\x16\x00\x00\x00",
        "{key: -5.0d}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ByteArrayTag([])}), "name"),
        b"\n\x00\x04name\x07\x00\x03key\x00\x00\x00\x00\x00",
        b"\n\x04\x00name\x07\x03\x00key\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMeg`\xceN\xadd\x00\x01\x00T~\x8a\x8e\x12\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMegf\xc8N\xadd\x00\x01\x00\xda\x92\t\xfb\x12\x00\x00\x00",
        "{key: [B;]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ByteArrayTag([5, 6, 7])}), "name"),
        b"\n\x00\x04name\x07\x00\x03key\x00\x00\x00\x03\x05\x06\x07\x00",
        b"\n\x04\x00name\x07\x03\x00key\x03\x00\x00\x00\x05\x06\x07\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMeg`\xceN\xadd```fecg\x00\x00!\x01\x97\x13\x15\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMegf\xc8N\xaddf```ecg\x00\x00\x97$i\xb7\x15\x00\x00\x00",
        "{key: [B;5B, 6B, 7B]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ByteArrayTag([-5, -6, -7])}), "name"),
        b"\n\x00\x04name\x07\x00\x03key\x00\x00\x00\x03\xfb\xfa\xf9\x00",
        b"\n\x04\x00name\x07\x03\x00key\x03\x00\x00\x00\xfb\xfa\xf9\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccMeg`\xceN\xadd```\xfe\xfd\xeb'\x03\x002&\xcfC\x15\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccMegf\xc8N\xaddf``\xf8\xfd\xeb'\x03\x00\x84\x031\xe7\x15\x00\x00\x00",
        "{key: [B;-5B, -6B, -7B]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": IntArrayTag([])}), "name"),
        b"\n\x00\x04name\x0b\x00\x03key\x00\x00\x00\x00\x00",
        b"\n\x04\x00name\x0b\x03\x00key\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccM\xe5f`\xceN\xadd\x00\x01\x00\x93\xec\x90\x84\x12\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccM\xe5ff\xc8N\xadd\x00\x01\x00\x1d\x00\x13\xf1\x12\x00\x00\x00",
        "{key: [I;]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": IntArrayTag([5, 6, 7])}), "name"),
        b"\n\x00\x04name\x0b\x00\x03key\x00\x00\x00\x03\x00\x00\x00\x05\x00\x00\x00\x06\x00\x00\x00\x07\x00",
        b"\n\x04\x00name\x0b\x03\x00key\x03\x00\x00\x00\x05\x00\x00\x00\x06\x00\x00\x00\x07\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccM\xe5f`\xceN\xadd```\x06bV f\x03bv\x06\x00\x0c\xe5\xf9\xb4\x1e\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccM\xe5ff\xc8N\xaddf```\x05b6 f\x07b\x06\x00B\x8a\xf9+\x1e\x00\x00\x00",
        "{key: [I;5, 6, 7]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": IntArrayTag([-5, -6, -7])}), "name"),
        b"\n\x00\x04name\x0b\x00\x03key\x00\x00\x00\x03\xff\xff\xff\xfb\xff\xff\xff\xfa\xff\xff\xff\xf9\x00",
        b"\n\x04\x00name\x0b\x03\x00key\x03\x00\x00\x00\xfb\xff\xff\xff\xfa\xff\xff\xff\xf9\xff\xff\xff\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccM\xe5f`\xceN\xadd```\xfe\xff\xff\xffo \xfe\x05\xc4?\x19\x00\x13\x97\x14\x14\x1e\x00\x00\x00",
        b'\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccM\xe5ff\xc8N\xaddf``\xf8\xfd\xff\xff\xff_@\xfc\x13\x88\x19\x00|\x1c""\x1e\x00\x00\x00',
        "{key: [I;-5, -6, -7]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": LongArrayTag([])}), "name"),
        b"\n\x00\x04name\x0c\x00\x03key\x00\x00\x00\x00\x00",
        b"\n\x04\x00name\x0c\x03\x00key\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccM\xe5a`\xceN\xadd\x00\x01\x00\x10\xf9\xab\xad\x12\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccM\xe5af\xc8N\xadd\x00\x01\x00\x9e\x15(\xd8\x12\x00\x00\x00",
        "{key: [L;]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": LongArrayTag([5, 6, 7])}), "name"),
        b"\n\x00\x04name\x0c\x00\x03key\x00\x00\x00\x03\x00\x00\x00\x00\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07\x00",
        b"\n\x04\x00name\x0c\x03\x00key\x03\x00\x00\x00\x05\x00\x00\x00\x00\x00\x00\x00\x06\x00\x00\x00\x00\x00\x00\x00\x07\x00\x00\x00\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccM\xe5a`\xceN\xadd```f\x80\x00V(\xcd\x06\xa5\xd9\x19\x00\x90\xb9\xb8T*\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccM\xe5af\xc8N\xaddf```e\x80\x006(\xcd\x0e\xa5\x19\x00\xc1\xf7\x8d\xc8*\x00\x00\x00",
        "{key: [L;5L, 6L, 7L]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": LongArrayTag([-5, -6, -7])}), "name"),
        b"\n\x00\x04name\x0c\x00\x03key\x00\x00\x00\x03\xff\xff\xff\xff\xff\xff\xff\xfb\xff\xff\xff\xff\xff\xff\xff\xfa\xff\xff\xff\xff\xff\xff\xff\xf9\x00",
        b"\n\x04\x00name\x0c\x03\x00key\x03\x00\x00\x00\xfb\xff\xff\xff\xff\xff\xff\xff\xfa\xff\xff\xff\xff\xff\xff\xff\xf9\xff\xff\xff\xff\xff\xff\xff\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccM\xe5a`\xceN\xadd```\xfe\x0f\x01\xbf\xa1\xf4/(\xfd\x93\x01\x00\xbb\x1a\xbd\x07*\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccM\xe5af\xc8N\xaddf``\xf8\xfd\x1f\x02~A\xe9\x9fP\x9a\x01\x00\x80\xb7\x9cg*\x00\x00\x00",
        "{key: [L;-5L, -6L, -7L]}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": StringTag("value")}), "name"),
        b"\n\x00\x04name\x08\x00\x03key\x00\x05value\x00",
        b"\n\x04\x00name\x08\x03\x00key\x05\x00value\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccM\xe5``\xceN\xadd`-K\xcc)Me\x00\x00$7\xe0n\x15\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccM\xe5`f\xc8N\xadde(K\xcc)Me\x00\x00bN\xe9\x19\x15\x00\x00\x00",
        '{key: "value"}',
    ),
    (
        NamedCompoundTag(CompoundTag({"key": ListTag([], 1)}), "name"),
        b"\n\x00\x04name\t\x00\x03key\x01\x00\x00\x00\x00\x00",
        b"\n\x04\x00name\t\x03\x00key\x01\x00\x00\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccM\xe5d`\xceN\xaddd\x00\x01\x00\xa5\xf0\xe7\x9c\x13\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccM\xe5df\xc8N\xaddd\x00\x01\x00n\xdd\x92\x96\x13\x00\x00\x00",
        "{key: []}",
    ),
    (
        NamedCompoundTag(CompoundTag({"key": CompoundTag({})}), "name"),
        b"\n\x00\x04name\n\x00\x03key\x00\x00",
        b"\n\x04\x00name\n\x03\x00key\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3b`\xc9K\xccM\xe5b`\xceN\xadd`\x00\x00v\xd5\xdf\xbc\x0f\x00\x00\x00",
        b"\x1f\x8b\x08\x00)\x83va\x02\xff\xe3ba\xc8K\xccM\xe5bf\xc8N\xadd`\x00\x00\xc8X\xb6\xd2\x0f\x00\x00\x00",
        "{key: {}}",
    ),
]

binary_data_tuple = tuple(Bin(*d) for d in binary_data)
